==> haskell-email-validate-2.3.2.16-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 email-validate
version:              2.3.2.16
visibility:           public
id:                   email-validate-2.3.2.16-In1ptxkMBuvHGVIs0j6Y2K
key:                  email-validate-2.3.2.16-In1ptxkMBuvHGVIs0j6Y2K
license:              BSD-3-Clause
maintainer:           George Pollard <porges@porg.es>
author:               George Pollard <porges@porg.es>
stability:            experimental
homepage:             https://github.com/Porges/email-validate-hs
synopsis:             Email address validation
description:          Validating an email address string against RFC 5322
category:             Text
abi:                  7b4d902b593e8d4a1cd5a3b363015ab2
exposed:              True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate

import-dirs:          /usr/lib/ghc-9.0.2/site-local/email-validate-2.3.2.16
library-dirs:         /usr/lib/ghc-9.0.2/site-local/email-validate-2.3.2.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-email-validate
hs-libraries:         HSemail-validate-2.3.2.16-In1ptxkMBuvHGVIs0j6Y2K
depends:
    attoparsec-0.14.4-C8JScaBf7EBAyHQottuuQN base-4.15.1.0
    bytestring-0.10.12.1 template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-email-validate/html/email-validate.haddock

haddock-html:         /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-email-validate-2.3.2.16-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 email-validate
version:              2.3.2.16
visibility:           public
id:                   email-validate-2.3.2.16-HgSOk1HiPs2JPr29UiMnHX
key:                  email-validate-2.3.2.16-HgSOk1HiPs2JPr29UiMnHX
license:              BSD-3-Clause
maintainer:           George Pollard <porges@porg.es>
author:               George Pollard <porges@porg.es>
stability:            experimental
homepage:             https://github.com/Porges/email-validate-hs
synopsis:             Email address validation
description:          Validating an email address string against RFC 5322
category:             Text
abi:                  c79d47f319070aeef7d940ff0dd10cbe
exposed:              True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate

import-dirs:          /usr/lib/ghc-9.0.2/site-local/email-validate-2.3.2.16
library-dirs:         /usr/lib/ghc-9.0.2/site-local/email-validate-2.3.2.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-email-validate
hs-libraries:         HSemail-validate-2.3.2.16-HgSOk1HiPs2JPr29UiMnHX
depends:
    attoparsec-0.14.4-5IzIDbgcbv25MsrsjK5Xz5 base-4.15.1.0
    bytestring-0.10.12.1 template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-email-validate/html/email-validate.haddock

haddock-html:         /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
